# Clock definition for the 156.25MHz FPGA reference clock
create_clock -period 6.400 -name fpga_ref_clk [get_ports sys_clk_p]

# MGT reference clock. Constrained for 156.25MHz
create_clock -period 6.400 -name mgt_ref_clk [get_ports refclk_p*]

# Async domains: all other clocks to/from freerun clock
set_clock_groups -asynchronous -group [get_clocks -of_objects [get_pins pll_inst/sys_clk]] -group [get_clocks -of_objects [get_pins pll_inst/freerun_clk]]
set_clock_groups -asynchronous -group [get_clocks -of_objects [get_pins TI_IP_inst/mgt_rx_usrclk2]] -group [get_clocks -of_objects [get_pins pll_inst/freerun_clk]]
set_clock_groups -asynchronous -group [get_clocks -of_objects [get_pins TI_IP_inst/mgt_tx_usrclk2]] -group [get_clocks -of_objects [get_pins pll_inst/freerun_clk]]

# Relaxed timing between rx_sys_clock and rx_usrclk2
set_max_delay -datapath_only -from [get_clocks -of_objects [get_pins TI_IP_inst/mgt_rx_usrclk2]] -to [get_clocks -of_objects [get_pins pll_inst/sys_clk]] 50.000
set_max_delay -datapath_only -from [get_clocks -of_objects [get_pins pll_inst/sys_clk]] -to [get_clocks -of_objects [get_pins TI_IP_inst/mgt_rx_usrclk2]] 50.000

# Relaxed timing between tx_sys_clock and tx_usrclk2
set_max_delay -datapath_only -from [get_clocks -of_objects [get_pins TI_IP_inst/mgt_tx_usrclk2]] -to [get_clocks -of_objects [get_pins pll_inst/sys_clk]] 50.000
set_max_delay -datapath_only -from [get_clocks -of_objects [get_pins pll_inst/sys_clk]] -to [get_clocks -of_objects [get_pins TI_IP_inst/mgt_tx_usrclk2]] 50.000

# Define a false path on master_reset_n
set_false_path -through [get_nets master_reset_n]

# Pin locations. To be modified based on target FPGA


set_property PACKAGE_PIN G27 [get_ports {refclk_p[0]}]

set_property PACKAGE_PIN AE5 [get_ports sys_clk_p]
set_property IOSTANDARD LVDS [get_ports sys_clk_p]
# set_property PACKAGE_PIN AG3 [get_ports cc_sysref_out_p]
# set_property IOSTANDARD LVDS [get_ports cc_sysref_out_p]
set_property PACKAGE_PIN AH1 [get_ports sysref_p]
set_property IOSTANDARD LVDS [get_ports sysref_p]
set_property PACKAGE_PIN AE3 [get_ports adc_rx_sync_n]
set_property IOSTANDARD LVCMOS18 [get_ports adc_rx_sync_n]
set_property PACKAGE_PIN AF3 [get_ports dac_tx_sync_n]
set_property IOSTANDARD LVCMOS18 [get_ports dac_tx_sync_n]

set_property C_CLK_INPUT_FREQ_HZ 300000000 [get_debug_cores dbg_hub]
set_property C_ENABLE_CLK_DIVIDER false [get_debug_cores dbg_hub]
set_property C_USER_SCAN_CHAIN 1 [get_debug_cores dbg_hub]
connect_debug_port dbg_hub/clk [get_nets mgt_freerun_clock]
